==> nocc-1.8.3.tbz: www/nocc/lang/cy.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: cy.php 2181 2010-04-27 09:07:03Z gerundt $
 */

/** Welsh (Cymraeg)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Lloffiwr
 * @author Sion Pennant <sion.pennant@powys.gov.uk>
 */

$lang_locale = 'cy_GB.UTF-8';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Mae\'r blwch mewngofnodi\'n wag';
$err_passwd_empty = 'Mae\'r blwch cyfrinair yn wag';
$alt_delete = 'Dileu\'r negeseuon sydd wedi eu dewis';
$alt_delete_one = 'Dileu\'r neges';
$alt_new_msg = 'Negeseuon newydd';
$alt_reply = 'Ymateb i\'r awdur';
$alt_reply_all = 'Ymateb i bawb';
$alt_forward = 'Gyrru ymlaen';
$alt_next = 'Nesaf';
$alt_prev = 'Blaenorol';
$title_next_page = 'Tudalen nesaf';
$title_prev_page = 'Tudalen flaenorol';
$title_next_msg = 'Neges nesaf';
$title_prev_msg = 'Neges flaenorol';
$html_theme_label = 'Thema:';
$html_welcome = 'Croeso i %1$s';
$html_login = 'Mewngofnodi';
$html_user_label = 'Defnyddiwr:';
$html_passwd_label = 'Cyfrinair:';
$html_submit = 'Gyrru';
$html_help = 'Cymorth';
$html_server_label = 'Gweinydd:';
$html_wrong = 'Mae eich enw mewngofnodi neu eich cyfrinair yn anghywir';
$html_retry = 'Ailgeisio';
$html_remember = 'Cofio\'r dewisiadau';
$html_lang_label = 'Iaith:';
$html_msgperpage_label = 'Nifer y negeseuon ar bob tudalen:';
$html_preferences = 'Dewisiadau';
$html_full_name_label = 'Enw llawn:';
$html_email_address_label = 'Cyfeiriad E-bost:';
$html_ccself = 'Cc atof fy hunan';
$html_hide_addresses = 'Cuddio cyfeiriadau';
$html_outlook_quoting = 'Dyfynodau tebyg i rai \'Outlook\'';
$html_reply_to = 'Ymateb i';
$html_use_signature = 'Defnyddio llofnod';
$html_signature = 'Llofnod';
$html_signature_label = 'Llofnod:';
$html_reply_leadin_label = 'Testun i\'w roi ar ddechrau ymateb:';
$html_prefs_updated = 'Diweddarwyd y dewisiadau';
$html_manage_folders_link = 'Trefnu\'r Ffolderi IMAP';
$html_manage_filters_link = 'Trefnu\'r Hidlau E-bost';
$html_use_graphical_smilies = 'Defnyddio wynebau graffigol';
$html_sent_folder_label = 'Copïo negeseuon anfonedig i ffolder bwrpasol:';
$html_trash_folder_label = 'Symud e-byst dilëedig i ffolder bwrpasol:';
$html_colored_quotes = 'Dyfynodau lliw';
$html_display_struct = 'Dangos testun strwythuredig';
$html_send_html_mail = 'Gyrru negeseuon mewn fformat HTML';
$html_folders = 'Ffolderi';
$html_folders_create_failed = 'Wedi methu creu ffolder!';
$html_folders_sub_failed = 'Wedi methu tanysgrifio i\'r ffolder!';
$html_folders_unsub_failed = 'Wedi methu dad-danysgrifio i\'r ffolder!';
$html_folders_rename_failed = 'Wedi methu ailenwi\'r ffolder!';
$html_folders_updated = 'Diweddarwyd y ffolderi';
$html_folder_subscribe = 'Tanysgrifio i';
$html_folder_rename = 'Ailenwi';
$html_folder_create = 'Creu ffolder newydd o\'r enw';
$html_folder_remove = 'Dad-danysgrifio i';
$html_folder_delete = 'Dileu';
$html_folder_to = 'yn';
$html_filter_remove = 'Dileu';
$html_filter_body = 'Sylwedd y neges';
$html_filter_subject = 'Pwnc';
$html_filter_to = 'Y maes At';
$html_filter_cc = 'Y maes Cc';
$html_filter_from = 'Y maes Oddi Wrth';
$html_filter_change_tip = 'I newid hidlen, tros-ysgrifennwch.';
$html_reapply_filters = 'Ailosod pob hidlen';
$html_filter_contains = 'yn cynnwys';
$html_filter_name = 'Enw\'r Hidlen';
$html_filter_action = 'Gweithrediadau Hidlo';
$html_filter_moveto = 'Symud i';
$html_select_one = '-- Dewiswch un --';
$html_and = 'A';
$html_new_msg_in = 'Neges newydd yn';
$html_or = 'neu';
$html_move = 'Symud';
$html_copy = 'Copïo';
$html_messages_to = 'y negeseuon dewisedig i\'r';
$html_gotopage = 'Mynd i Dudalen';
$html_gotofolder = 'Mynd i\'r Ffolder';
$html_other_folders = 'Rhestr Ffolderi';
$html_page = 'Tudalen';
$html_of = 'o';
$html_view_header = 'Gweld y pennyn';
$html_remove_header = 'Cuddio\'r pennyn';
$html_inbox = 'Blwch Derbyn';
$html_new_msg = 'Ysgrifennu';
$html_reply = 'Ymateb';
$html_reply_short = 'Re:';
$html_reply_all = 'Ymateb i bawb';
$html_forward = 'Anfon Ymlaen';
$html_forward_short = 'Yml:';
$html_forward_info = 'Bydd y neges yn cael ei hanfon ymlaen fel atodiad i\'r neges hon.';
$html_delete = 'Dileu';
$html_new = 'Newydd';
$html_mark = 'Dileu';
$html_att_label = 'Atodiad:';
$html_atts_label = 'Ymgysylltiadau:';
$html_unknown = '[anhysbys]';
$html_attach = 'Atodi';
$html_attach_forget = 'Rhaid i chi atodi\'r ffeil cyn anfon y neges!';
$html_attach_delete = 'Datod y ffeiliau dewisedig';
$html_attach_none = 'Dewiswch ffeil i\'w hatodi!';
$html_sort_by = 'Trefnu yn ôl';
$html_sort = 'Trefnu';
$html_from = 'Oddi wrth';
$html_from_label = 'Oddi wrth:';
$html_subject = 'Pwnc';
$html_subject_label = 'Pwnc:';
$html_date = 'Dyddiad';
$html_date_label = 'Dyddiad:';
$html_sent_label = 'Anfon:';
$html_wrote = 'wedi ysgrifennu';
$html_size = 'Maint';
$html_totalsize = 'Cyfanswm maint';
$html_kb = 'kb';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'beit';
$html_filename = 'Enw ffeil';
$html_to = 'At';
$html_to_label = 'At:';
$html_cc = 'Cc';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Bcc:';
$html_nosubject = 'Di-bwnc';
$html_send = 'Anfon';
$html_cancel = 'Canslo';
$html_no_mail = 'Dim negeseuon.';
$html_logout = 'Allgofnodi';
$html_msg = 'Neges';
$html_msgs = 'Negeseuon';
$html_configuration = 'Nid yw\'r gweinydd yma wedi cael ei ffurfweddu (gosod) yn iawn!';
$html_priority = 'Blaenoriaeth';
$html_priority_label = 'Blaenoriaeth:';
$html_lowest = 'Isel iawn';
$html_low = 'Isel';
$html_normal = 'Normal';
$html_high = 'Uchel';
$html_highest = 'Uchel iawn';
$html_flagged = 'Wedi\'i llumanu';
$html_spam = 'Sbam';
$html_spam_warning = 'Mae\'r neges hon yn cael ei thrin fel sbam.';
$html_receipt = 'Gwneud cais am dderbynneb';
$html_select = 'Dewiswch';
$html_select_all = 'Gwrthdroi\'r Detholiad';
$html_select_contacts = 'Dewis y cysylltiadau';
$html_loading_image = 'Wrthi\'n llwytho\'r ddelwedd';
$html_send_confirmed = 'Derbyniwyd eich neges ar gyfer cludiant';
$html_no_sendaction = 'Dim gweithredoedd wedi eu pennu. Gwiriwch fod JavaScript wedi cael ei alluogi yn eich porwr.';
$html_error_occurred = 'Gwall';
$html_prefs_file_error = 'Methu agor y ffeil ddewisiadau ar gyfer ysgrifennu.';
$html_wrap = 'Nifer y nodau i\'w hamlapio mewn testun neges i\'w ddanfon:';
$html_wrap_none = 'Dim amlapio';
$html_usenet_separator = 'Gwahanydd Usenet ("-- \n") cyn y llofnod';
$html_mark_as = 'Marcio ei bod';
$html_read = 'wedi ei darllen';
$html_unread = 'heb ei darllen';
$html_encoding_label = 'Amgodio nodau:';
$html_add = 'Adio';
$html_contacts = '%1$s o gysylltiadau';
$html_modify = 'Addasu';
$html_back = 'Yn ôl';
$html_contact_add = 'Adio cyswllt newydd';
$html_contact_mod = 'Newid manylion cyswllt';
$html_contact_first = 'Enw cyntaf';
$html_contact_last = 'Cyfenw';
$html_contact_nick = 'Llysenw';
$html_contact_mail = 'Cyfeiriad E-bost';
$html_contact_list = 'Rhestr cysylltiadau %1$s';
$html_contact_del = 'o\'r rhestr gysylltiadau';
$html_contact_count = '%1$d o gysylltiadau';
$html_contact_err1 = 'Uchafswm nifer y cysylltiadau yw "%1$d"';
$html_contact_err2 = 'Fedrwch chi ddim adio cyswllt newydd';
$html_contact_err3 = 'Nid oes gennych hawl mynediad i\'r rhestr gysylltiadau';
$html_contact_none = 'Dim cysylltiadau i gael.';
$html_del_msg = 'Dileu\'r negeseuon dewisedig?';
$html_down_mail = 'Islwytho';
$original_msg = '-- Y Neges Wreiddiol --';
$to_empty = 'Rhaid i chi lenwi\'r maes \'I\'!';
$html_images_warning = 'Er mwyn eich diogelu, nid yw delweddau pell yn cael eu harddangos.';
$html_images_display = 'Dangos delweddau';
$html_smtp_error_no_conn = 'Methu agor cyswllt SMTP';
$html_smtp_error_unexpected = 'Ymateb SMTP annisgwyledig:';
$lang_could_not_connect = 'Yn methu cysylltu â\'r gweinydd';
$lang_invalid_msg_num = 'Gwall ar rif y neges';
$html_file_upload_attack = 'Ymosodiad uwchlwytho ffeil posibl';
$html_invalid_email_address = 'Cyfeiriad e-bost annilys';
$html_invalid_msg_per_page = 'Nifer annilys o negeseuon y dudalen';
$html_invalid_wrap_msg = 'Lled amlapio neges annilys';
$html_seperate_msg_win = 'Negeseuon mewn ffenestr arall';
$html_err_file_contacts = 'Yn methu agor ffeil y cysylltiadau ar gyfer ysgrifennu.';
$html_session_file_error = 'Yn methu agor ffeil sesiynau ar gyfer ysgrifennu.';
$html_login_not_allowed = 'Nid yw\'r mewngofnodiad yma\'n ddilys ar gyfer y cyswllt hwn.';
$lang_err_send_delay = 'Rhaid oedi cyn anfon e-bost arall (%1$d eiliad)';
$html_search = 'Chwilio';

==> nocc-1.9.1.tbz: www/nocc/lang/cy.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: cy.php 2396 2011-02-14 16:47:29Z siebrand $
 */
/** Welsh (Cymraeg)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Lloffiwr
 * @author Sion Pennant <sion.pennant@powys.gov.uk>
 */

$lang_locale = 'cy_GB.UTF-8';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Mae\'r blwch mewngofnodi\'n wag';
$err_passwd_empty = 'Mae\'r blwch cyfrinair yn wag';
$alt_delete = 'Dileu\'r negeseuon sydd wedi eu dewis';
$alt_delete_one = 'Dileu\'r neges';
$alt_new_msg = 'Negeseuon newydd';
$alt_reply = 'Ymateb i\'r awdur';
$alt_reply_all = 'Ymateb i bawb';
$alt_forward = 'Gyrru ymlaen';
$alt_next = 'Nesaf';
$alt_prev = 'Blaenorol';
$title_next_page = 'Tudalen nesaf';
$title_prev_page = 'Tudalen flaenorol';
$title_next_msg = 'Neges nesaf';
$title_prev_msg = 'Neges flaenorol';
$html_theme_label = 'Thema:';
$html_welcome = 'Croeso i %1$s';
$html_login = 'Mewngofnodi';
$html_user_label = 'Defnyddiwr:';
$html_passwd_label = 'Cyfrinair:';
$html_submit = 'Gyrru';
$html_help = 'Cymorth';
$html_server_label = 'Gweinydd:';
$html_wrong = 'Mae eich enw mewngofnodi neu eich cyfrinair yn anghywir';
$html_retry = 'Ailgeisio';
$html_remember = 'Cofio\'r dewisiadau';
$html_lang_label = 'Iaith:';
$html_msgperpage_label = 'Nifer y negeseuon ar bob tudalen:';
$html_preferences = 'Dewisiadau';
$html_full_name_label = 'Enw llawn:';
$html_email_address_label = 'Cyfeiriad E-bost:';
$html_bccself = 'Anfon copi preifat atof fy hunan';
$html_hide_addresses = 'Cuddio cyfeiriadau';
$html_outlook_quoting = 'Dyfynodau tebyg i rai \'Outlook\'';
$html_reply_to = 'Ymateb i';
$html_use_signature = 'Defnyddio llofnod';
$html_signature = 'Llofnod';
$html_signature_label = 'Llofnod:';
$html_reply_leadin_label = 'Testun i\'w roi ar ddechrau ymateb:';
$html_prefs_updated = 'Diweddarwyd y dewisiadau';
$html_manage_folders_link = 'Trefnu\'r Ffolderi IMAP';
$html_manage_filters_link = 'Trefnu\'r Hidlau E-bost';
$html_use_graphical_smilies = 'Defnyddio wynebau graffigol';
$html_sent_folder_label = 'Copïo negeseuon anfonedig i ffolder bwrpasol:';
$html_trash_folder_label = 'Symud e-byst dilëedig i ffolder bwrpasol:';
$html_colored_quotes = 'Dyfynodau lliw';
$html_display_struct = 'Dangos testun strwythuredig';
$html_send_html_mail = 'Gyrru negeseuon mewn fformat HTML';
$html_folders = 'Ffolderi';
$html_folders_create_failed = 'Wedi methu creu ffolder!';
$html_folders_sub_failed = 'Wedi methu tanysgrifio i\'r ffolder!';
$html_folders_unsub_failed = 'Wedi methu dad-danysgrifio i\'r ffolder!';
$html_folders_rename_failed = 'Wedi methu ailenwi\'r ffolder!';
$html_folders_updated = 'Diweddarwyd y ffolderi';
$html_folder_subscribe = 'Tanysgrifio i';
$html_folder_rename = 'Ailenwi';
$html_folder_create = 'Creu ffolder newydd o\'r enw';
$html_folder_remove = 'Dad-danysgrifio i';
$html_folder_delete = 'Dileu';
$html_folder_to = 'yn';
$html_filter_remove = 'Dileu';
$html_filter_body = 'Sylwedd y neges';
$html_filter_subject = 'Pwnc';
$html_filter_to = 'Y maes At';
$html_filter_cc = 'Y maes Cc';
$html_filter_from = 'Y maes Oddi Wrth';
$html_filter_change_tip = 'I newid hidlen, tros-ysgrifennwch.';
$html_reapply_filters = 'Ailosod pob hidlen';
$html_filter_contains = 'yn cynnwys';
$html_filter_name = 'Enw\'r Hidlen';
$html_filter_action = 'Gweithrediadau Hidlo';
$html_filter_moveto = 'Symud i';
$html_select_one = '-- Dewiswch un --';
$html_and = 'A';
$html_new_msg_in = 'Neges newydd yn';
$html_or = 'neu';
$html_move = 'Symud';
$html_copy = 'Copïo';
$html_messages_to = 'y negeseuon dewisedig i\'r';
$html_gotopage = 'Mynd i Dudalen';
$html_gotofolder = 'Mynd i\'r Ffolder';
$html_other_folders = 'Rhestr Ffolderi';
$html_page = 'Tudalen';
$html_of = 'o';
$html_view_header = 'Gweld y pennyn';
$html_remove_header = 'Cuddio\'r pennyn';
$html_inbox = 'Blwch Derbyn';
$html_new_msg = 'Ysgrifennu';
$html_reply = 'Ymateb';
$html_reply_short = 'Re:';
$html_reply_all = 'Ymateb i bawb';
$html_forward = 'Anfon Ymlaen';
$html_forward_short = 'Yml:';
$html_forward_info = 'Bydd y neges yn cael ei hanfon ymlaen fel atodiad i\'r neges hon.';
$html_delete = 'Dileu';
$html_new = 'Newydd';
$html_mark = 'Dileu';
$html_att_label = 'Atodiad:';
$html_atts_label = 'Ymgysylltiadau:';
$html_unknown = '[anhysbys]';
$html_part_x = 'Rhan %s';
$html_attach = 'Atodi';
$html_attach_forget = 'Rhaid i chi atodi\'r ffeil cyn anfon y neges!';
$html_attach_delete = 'Datod y ffeiliau dewisedig';
$html_attach_none = 'Dewiswch ffeil i\'w hatodi!';
$html_sort_by = 'Trefnu yn ôl';
$html_sort = 'Trefnu';
$html_from = 'Oddi wrth';
$html_from_label = 'Oddi wrth:';
$html_subject = 'Pwnc';
$html_subject_label = 'Pwnc:';
$html_date = 'Dyddiad';
$html_date_label = 'Dyddiad:';
$html_sent_label = 'Anfon:';
$html_wrote = 'wedi ysgrifennu';
$html_size = 'Maint';
$html_totalsize = 'Cyfanswm maint';
$html_kb = 'kb';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'beit';
$html_filename = 'Enw ffeil';
$html_to = 'At';
$html_to_label = 'At:';
$html_cc = 'Cc';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Bcc:';
$html_nosubject = 'Di-bwnc';
$html_send = 'Anfon';
$html_cancel = 'Canslo';
$html_no_mail = 'Dim negeseuon.';
$html_logout = 'Allgofnodi';
$html_msg = 'Neges';
$html_msgs = 'Negeseuon';
$html_configuration = 'Nid yw\'r gweinydd yma wedi cael ei ffurfweddu (gosod) yn iawn!';
$html_priority = 'Blaenoriaeth';
$html_priority_label = 'Blaenoriaeth:';
$html_lowest = 'Isel iawn';
$html_low = 'Isel';
$html_normal = 'Normal';
$html_high = 'Uchel';
$html_highest = 'Uchel iawn';
$html_flagged = 'Wedi\'i llumanu';
$html_spam = 'Sbam';
$html_spam_warning = 'Mae\'r neges hon yn cael ei thrin fel sbam.';
$html_receipt = 'Gwneud cais am dderbynneb';
$html_select = 'Dewiswch';
$html_select_all = 'Gwrthdroi\'r Detholiad';
$html_select_contacts = 'Dewis y cysylltiadau';
$html_loading_image = 'Wrthi\'n llwytho\'r ddelwedd';
$html_send_confirmed = 'Derbyniwyd eich neges ar gyfer cludiant';
$html_no_sendaction = 'Dim gweithredoedd wedi eu pennu. Gwiriwch fod JavaScript wedi cael ei alluogi yn eich porwr.';
$html_error_occurred = 'Gwall';
$html_prefs_file_error = 'Methu agor y ffeil ddewisiadau ar gyfer ysgrifennu.';
$html_wrap = 'Nifer y nodau i\'w hamlapio mewn testun neges i\'w ddanfon:';
$html_wrap_none = 'Dim amlapio';
$html_usenet_separator = 'Gwahanydd Usenet ("-- \n") cyn y llofnod';
$html_mark_as = 'Marcio ei bod';
$html_read = 'wedi ei darllen';
$html_unread = 'heb ei darllen';
$html_encoding_label = 'Amgodio nodau:';
$html_add = 'Adio';
$html_contacts = '%1$s o gysylltiadau';
$html_modify = 'Addasu';
$html_back = 'Yn ôl';
$html_contact_add = 'Adio cyswllt newydd';
$html_contact_mod = 'Newid manylion cyswllt';
$html_contact_first = 'Enw cyntaf';
$html_contact_last = 'Cyfenw';
$html_contact_nick = 'Llysenw';
$html_contact_mail = 'Cyfeiriad E-bost';
$html_contact_list = 'Rhestr cysylltiadau %1$s';
$html_contact_del = 'o\'r rhestr gysylltiadau';
$html_contact_count = '%1$d o gysylltiadau';
$html_contact_err1 = 'Uchafswm nifer y cysylltiadau yw "%1$d"';
$html_contact_err2 = 'Fedrwch chi ddim adio cyswllt newydd';
$html_contact_err3 = 'Nid oes gennych hawl mynediad i\'r rhestr gysylltiadau';
$html_contact_none = 'Dim cysylltiadau i gael.';
$html_del_msg = 'Dileu\'r negeseuon dewisedig?';
$html_down_mail = 'Islwytho';
$original_msg = '-- Y Neges Wreiddiol --';
$to_empty = 'Rhaid i chi lenwi\'r maes \'I\'!';
$html_images_warning = 'Er mwyn eich diogelu, nid yw delweddau pell yn cael eu harddangos.';
$html_images_display = 'Dangos delweddau';
$html_smtp_error_no_conn = 'Methu agor cyswllt SMTP';
$html_smtp_error_unexpected = 'Ymateb SMTP annisgwyledig:';
$lang_could_not_connect = 'Yn methu cysylltu â\'r gweinydd';
$lang_invalid_msg_num = 'Gwall ar rif y neges';
$html_file_upload_attack = 'Ymosodiad uwchlwytho ffeil posibl';
$html_invalid_email_address = 'Cyfeiriad e-bost annilys';
$html_invalid_msg_per_page = 'Nifer annilys o negeseuon y dudalen';
$html_invalid_wrap_msg = 'Lled amlapio neges annilys';
$html_seperate_msg_win = 'Negeseuon mewn ffenestr arall';
$html_err_file_contacts = 'Yn methu agor ffeil y cysylltiadau ar gyfer ysgrifennu.';
$html_session_file_error = 'Yn methu agor ffeil sesiynau ar gyfer ysgrifennu.';
$html_login_not_allowed = 'Nid yw\'r mewngofnodiad yma\'n ddilys ar gyfer y cyswllt hwn.';
$lang_err_send_delay = 'Rhaid oedi cyn anfon e-bost arall (%1$d eiliad)';
$html_search = 'Chwilio';
